@@ -10,6 +10,7 @@ import re
 
 import wrapt
 
+from lunchbox.enforce import Enforce
 from lunchbox.stopwatch import StopWatch
 
 LOG_LEVEL = os.environ.get('LOG_LEVEL', 'WARNING').upper()
@@ -116,6 +117,85 @@ def relative_path(module, path):
     return output
 
 
+def truncate_list(items, size=3):
+    # type (list, int) -> list
+    '''
+    Truncates a given list to a given size, replaces the middle contents with
+    "...".
+
+    Args:
+        items (list): List of objects.
+        size (int, optional): Size of output list.
+
+    Raises:
+        EnforceError: If item is not a list.
+        EnforceError: If size is not an integer greater than -1.
+
+    Returns:
+        list: List of given size.
+    '''
+    Enforce(items, 'instance of', list, message='Items must be a list.')
+    msg = 'Size must be an integer greater than -1. Given value: {a}.'
+    Enforce(size, 'instance of', int, message=msg)
+    Enforce(size, '>', -1, message=msg)
+    # --------------------------------------------------------------------------
+
+    if len(items) <= size:
+        return items
+    if size == 0:
+        return []
+    if size == 1:
+        return items[:1]
+    if size == 2:
+        return [items[0], items[-1]]
+
+    output = items[:size - 2]
+    output.append('...')
+    output.append(items[-1])
+    return output
+
+
+def truncate_blob_lists(blob, size=3):
+    # type: (dict, int) -> dict
+    '''
+    Truncates lists inside given JSON blob to a given size.
+
+    Args:
+        blob (dict): Blob to be truncated.
+        size (int, optional): Size of lists. Default 3.
+
+    Raises:
+        EnforceError: If blob is not a dict.
+
+    Returns:
+        dict: Truncated blob.
+    '''
+    Enforce(blob, 'instance of', dict, message='Blob must be a dict.')
+    # --------------------------------------------------------------------------
+
+    def recurse_list(items, size):
+        output = []
+        for item in truncate_list(items, size=size):
+            if isinstance(item, dict):
+                item = recurse(item)
+            elif isinstance(item, list):
+                item = recurse_list(item, size)
+            output.append(item)
+        return output
+
+    def recurse(item):
+        output = {}
+        for k, v in item.items():
+            if isinstance(v, dict):
+                output[k] = recurse(v)
+            elif isinstance(v, list):
+                output[k] = recurse_list(v, size)
+            else:
+                output[k] = v
+        return output
+    return recurse(blob)
+
+
 # LOGGING-----------------------------------------------------------------------
 def log_runtime(function, *args, message_=None, _testing=False, **kwargs):
     # type (Callable, ..., Optional[str], bool, ...) -> Any
